import zhCN from '@/locales/zh-CN/comtable.js'
import enUS from '@/locales/en-US/comtable.js'

const Formdict = localStorage.getItem('lang') !== 'en-US' ? zhCN : enUS

/**
 * @description 获取搜索条件表单配置信息
 * @param {*} card 
 */
export function getSearchForm (card, roleList = []) {
  return [
    {
      type: 'text',
      key: 'label',
      label: Formdict['header.form.name'],
      initVal: card.label || '',
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'field',
      label: Formdict['header.form.field'],
      initVal: card.field || '',
      tooltip: '字段名可以使用逗号分隔，进行多字段综合搜索，注：综合搜索仅在文本类型时有效',
      tooltipClass: 'middle',
      required: true,
      readonly: false
    },
    {
      type: 'select',
      key: 'type',
      label: Formdict['header.form.type'],
      initVal: card.type,
      required: true,
      options: [{
        value: 'text',
        text: Formdict['header.form.text']
      }, {
        value: 'select',
        text: Formdict['header.form.select']
      }, {
        value: 'multiselect',
        text: Formdict['header.form.multiselect']
      }, {
        value: 'link',
        text: Formdict['header.form.link']
      }, {
        value: 'date',
        text: Formdict['header.form.dateday']
      }, {
        value: 'dateweek',
        text: Formdict['header.form.dateweek']
      }, {
        value: 'datemonth',
        text: Formdict['header.form.datemonth']
      }, {
        value: 'daterange',
        text: Formdict['header.form.daterange']
      }]
    },
    {
      type: 'text',
      key: 'initval',
      label: Formdict['header.form.initval'],
      initVal: card.initval,
      required: false
    },
    {
      type: 'radio',
      key: 'resourceType',
      label: Formdict['header.form.resourceType'],
      initVal: card.resourceType || '0',
      required: true,
      options: [{
        value: '0',
        text: Formdict['header.form.custom']
      }, {
        value: '1',
        text: Formdict['header.form.datasource']
      }]
    },
    {
      type: 'radio',
      key: 'setAll',
      label: Formdict['header.form.setAll'],
      initVal: card.setAll || 'false',
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'textarea',
      key: 'dataSource',
      label: Formdict['header.form.datasource'],
      initVal: card.dataSource || '',
      required: true,
      readonly: false
    },
    {
      type: 'options',
      key: 'options',
      label: '',
      initVal: card.options || [],
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'linkField',
      label: Formdict['header.form.linkField'],
      initVal: card.linkField || '',
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'valueField',
      label: Formdict['header.form.valueField'],
      initVal: card.valueField || '',
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'valueText',
      label: Formdict['header.form.valueText'],
      initVal: card.valueText || '',
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'orderBy',
      label: Formdict['header.form.orderBy'],
      initVal: card.orderBy || '',
      required: false,
      readonly: false
    },
    {
      type: 'select',
      key: 'orderType',
      label: Formdict['header.form.orderType'],
      initVal: card.orderType || 'asc',
      options: [{
        value: 'asc',
        text: Formdict['header.form.asc']
      }, {
        value: 'desc',
        text: Formdict['header.form.desc']
      }]
    },
    {
      type: 'select',
      key: 'match',
      label: Formdict['header.form.match'],
      initVal: card.match || 'like',
      required: true,
      options: [{
        value: 'like',
        text: 'like'
      }, {
        value: 'equal',
        text: 'equal'
      }, {
        value: 'greater',
        text: '>'
      }, {
        value: 'less',
        text: '<'
      }, {
        value: 'greaterequal',
        text: '>='
      }]
    },
    {
      type: 'select',
      key: 'display',
      label: Formdict['header.form.display'],
      initVal: card.display || 'dropdown',
      required: true,
      options: [{
        value: 'dropdown',
        text: Formdict['header.form.dropdown']
      }, {
        value: 'button',
        text: Formdict['header.form.button']
      }]
    },
    {
      type: 'radio',
      key: 'database',
      label: Formdict['header.form.database'],
      initVal: card.database || 'local',
      options: [{
        value: 'local',
        text: Formdict['header.form.database.local']
      }, {
        value: 'sso',
        text: Formdict['header.form.database.sso']
      }]
    },
    {
      type: 'radio',
      key: 'required',
      label: Formdict['header.form.field.required'],
      initVal: card.required || 'false',
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'number',
      key: 'ratio',
      min: 1,
      max: 24,
      label: Formdict['header.form.ratio'],
      tooltip: '每行分为24份，比例可设置为1-24',
      initVal: card.ratio,
      required: false
    },
    {
      type: 'select',
      key: 'quick',
      label: Formdict['header.form.quickadd'],
      initVal: '',
      required: false,
      options: []
    },
    {
      type: 'multiselect',
      key: 'blacklist',
      label: Formdict['header.form.blacklist'],
      initVal: card.blacklist || [],
      required: false,
      options: roleList
    }
  ]
}

/**
 * @description 获取按钮表单配置信息
 * @param {*} card           编辑按钮
 * @param {*} functip        生成存储过程提示
 * @param {*} config         页面配置
 * @param {*} permFuncField  存储过程可用的开始字段
 */
export function getActionForm (card, functip, config, permFuncField) {
  return [
    {
      type: 'text',
      key: 'label',
      label: Formdict['header.form.name'],
      initVal: card.label,
      required: true,
      readonly: false
    },
    {
      type: 'select',
      key: 'OpenType',
      label: Formdict['header.form.openType'],
      initVal: card.OpenType,
      required: true,
      options: [{
        value: 'pop',
        text: Formdict['header.form.popform']
      }, {
        value: 'prompt',
        text: Formdict['header.form.prompt']
      }, {
        value: 'exec',
        text: Formdict['header.form.exec']
      }, {
        value: 'excelIn',
        text: Formdict['header.form.excelIn']
      }, {
        value: 'excelOut',
        text: Formdict['header.form.excelOut']
      }, {
        value: 'popview',
        text: Formdict['header.form.popview']
      }, {
        value: 'tab',
        text: Formdict['header.form.tab']
      }, {
        value: 'blank',
        text: Formdict['header.form.blank']
      }, {
        value: 'innerpage',
        text: Formdict['header.form.newpage.inner']
      }, {
        value: 'outerpage',
        text: Formdict['header.form.newpage.outer']
      }, {
        value: 'funcbutton',
        text: Formdict['header.form.funcbutton']
      }]
    },
    {
      type: 'select',
      key: 'funcType',
      label: Formdict['header.form.funcType'],
      initVal: card.funcType || '',
      required: true,
      options: [{
        value: 'changeuser',
        text: Formdict['header.form.func.changeuser']
      }, {
        value: 'print',
        text: Formdict['header.form.func.print']
      }]
    },
    {
      type: 'select',
      key: 'execMode',
      label: Formdict['header.form.execMode'],
      initVal: card.execMode || 'exec',
      required: true,
      options: [{
        value: 'exec',
        text: Formdict['header.form.exec']
      }, {
        value: 'prompt',
        text: Formdict['header.form.prompt']
      }, {
        value: 'pop',
        text: Formdict['header.form.popform']
      }]
    },
    {
      type: 'select',
      key: 'tabType',
      label: Formdict['header.form.tabType'],
      initVal: card.tabType || 'SubTable',
      required: true,
      options: [{
        value: 'SubTable',
        text: Formdict['header.menu.tab.subtable']
      }]
    },
    {
      type: 'select',
      key: 'linkTab',
      label: '关联标签',
      initVal: card.linkTab || '',
      required: false,
      options: []
    },
    {
      type: 'select',
      key: 'pageTemplate',
      label: Formdict['header.form.newpage.type'],
      initVal: card.pageTemplate || '',
      required: true,
      options: [{
        value: 'print',
        text: Formdict['header.menu.printTemplate']
      }]
    },
    {
      type: 'text',
      key: 'url',
      label: Formdict['header.form.newpage.url'],
      initVal: card.url || '',
      required: true
    },
    {
      type: 'radio',
      key: 'intertype',
      label: Formdict['header.form.intertype'],
      initVal: card.intertype || 'inner',
      required: true,
      options: [{
        value: 'inner',
        text: Formdict['header.form.interface.inner']
      }, {
        value: 'outer',
        text: Formdict['header.form.interface.outer']
      }]
    },
    {
      type: 'text',
      key: 'innerFunc',
      label: Formdict['header.form.innerFunc'],
      initVal: card.innerFunc || '',
      tooltip: functip,
      fields: permFuncField,
      tooltipClass: 'middle',
      required: false,
      readonly: false
    },
    {
      type: 'radio',
      key: 'sysInterface',
      label: Formdict['header.form.sysInterface'],
      initVal: card.sysInterface || 'false',
      required: true,
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'text',
      key: 'outerFunc',
      label: Formdict['header.form.outerFunc'],
      initVal: card.outerFunc || '',
      required: false,
      readonly: false
    },
    {
      type: 'text',
      key: 'interface',
      label: Formdict['header.form.interface'],
      initVal: card.sysInterface === 'true' ? (window.GLOB.mainSystemApi || window.GLOB.subSystemApi) : (card.interface || ''),
      required: true,
      readonly: card.sysInterface === 'true'
    },
    {
      type: 'text',
      key: 'callbackFunc',
      label: Formdict['header.form.callbackFunc'],
      initVal: card.callbackFunc || '',
      required: false,
      readonly: false
    },
    {
      type: 'select',
      key: 'position',
      label: Formdict['header.form.position'],
      initVal: card.position || 'toolbar',
      required: true,
      options: [{
        value: 'toolbar',
        text: Formdict['header.form.toolbar']
      }, {
        value: 'grid',
        text: Formdict['header.form.grid']
      }]
    },
    {
      type: 'select',
      key: 'Ot',
      label: Formdict['header.form.isRequired'],
      initVal: card.Ot || 'requiredSgl',
      required: true,
      options: []
    },
    {
      type: 'select',
      key: 'tabTemplate',
      label: '标签模板',
      initVal: card.tabTemplate || 'FormTab',
      required: true,
      options: [{
        value: 'FormTab',
        text: '带标签表单'
      }]
    },
    {
      type: 'select',
      key: 'afterExecSuccess',
      label: Formdict['header.form.afterExecSuccess'],
      initVal: card.afterExecSuccess || 'close',
      required: true,
      options: [{
        value: 'close',
        text: Formdict['header.close']
      }, {
        value: 'notclose',
        text: Formdict['header.notclose']
      }]
    },
    {
      type: 'select',
      key: 'afterExecError',
      label: Formdict['header.form.afterExecError'],
      initVal: card.afterExecError || 'notclose',
      required: true,
      options: [{
        value: 'close',
        text: Formdict['header.close']
      }, {
        value: 'notclose',
        text: Formdict['header.notclose']
      }]
    },
    {
      type: 'select',
      key: 'execSuccess',
      label: Formdict['header.form.execSuccess'],
      initVal: card.execSuccess || 'never',
      required: true,
      options: [{
        value: 'never',
        text: Formdict['header.form.refresh.never']
      }, {
        value: 'grid',
        text: Formdict['header.form.refresh.grid']
      }, {
        value: 'view',
        text: Formdict['header.form.refresh.view']
      }]
    },
    {
      type: 'select',
      key: 'execError',
      label: Formdict['header.form.execError'],
      initVal: card.execError || 'never',
      required: true,
      options: [{
        value: 'never',
        text: Formdict['header.form.refresh.never']
      }, {
        value: 'grid',
        text: Formdict['header.form.refresh.grid']
      }, {
        value: 'view',
        text: Formdict['header.form.refresh.view']
      }]
    },
    {
      type: 'select',
      key: 'popClose',
      label: Formdict['header.form.popClose'],
      initVal: card.popClose || 'never',
      required: true,
      options: [{
        value: 'never',
        text: Formdict['header.form.refresh.never']
      }, {
        value: 'grid',
        text: Formdict['header.form.refresh.grid']
      }, {
        value: 'view',
        text: Formdict['header.form.refresh.view']
      }]
    },
    {
      type: 'select',
      key: 'icon',
      label: Formdict['header.form.icon'],
      initVal: card.icon,
      required: false,
      options: []
    },
    {
      type: 'select',
      key: 'class',
      label: Formdict['header.form.class'],
      initVal: card.class,
      required: false,
      options: []
    },
    {
      type: 'text',
      key: 'sheet',
      label: Formdict['header.form.tablename'],
      initVal: card.sheet || config.setting.tableName || '',
      required: true
    },
    {
      type: 'text',
      key: 'sql',
      label: Formdict['header.form.tablename'],
      initVal: card.sql || config.setting.tableName || '',
      tooltip: Formdict['header.form.actionhelp.tablename'],
      required: false
    },
    {
      type: 'select',
      key: 'sqlType',
      label: Formdict['header.form.action.type'],
      initVal: card.sqlType || '',
      tooltip: Formdict['header.form.actionhelp.sqlType'],
      required: false,
      options: []
    },
    {
      type: 'radio',
      key: 'pagination',
      label: Formdict['header.form.pagination'],
      initVal: card.pagination || 'false',
      required: false,
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    }
  ]
}

/**
 * @description 获取显示列表单配置信息
 * @param {*} card
 */
export function getColumnForm (card, roleList = [], menulist = []) {
  return [
    {
      type: 'text',
      key: 'label',
      label: Formdict['header.form.name'],
      initVal: card.label,
      required: true
    },
    {
      type: 'text',
      key: 'field',
      label: Formdict['header.form.field'],
      initVal: card.field,
      required: true,
      readonly: false
    },
    {
      type: 'select',
      key: 'type',
      label: Formdict['header.form.type'],
      initVal: card.type,
      required: true,
      options: [{
        value: 'text',
        text: Formdict['header.form.text']
      }, {
        value: 'number',
        text: Formdict['header.form.number']
      }, {
        value: 'picture',
        text: Formdict['header.form.picture']
      }, {
        value: 'textarea',
        text: Formdict['header.form.textarea']
      }]
    },
    {
      type: 'select',
      key: 'Align',
      label: Formdict['header.form.align'],
      initVal: card.Align,
      required: true,
      options: [{
        value: 'left',
        text: Formdict['header.form.alignLeft']
      }, {
        value: 'right',
        text: Formdict['header.form.alignRight']
      }, {
        value: 'center',
        text: Formdict['header.form.alignCenter']
      }]
    },
    {
      type: 'radio',
      key: 'Hide',
      label: Formdict['header.form.Hide'],
      initVal: card.Hide,
      required: true,
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'radio',
      key: 'IsSort',
      label: Formdict['header.form.IsSort'],
      initVal: card.IsSort,
      required: true,
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'number',
      key: 'Width',
      min: 1,
      max: 1000,
      decimal: 0,
      label: Formdict['header.form.columnWidth'],
      initVal: card.Width,
      required: true
    },
    {
      type: 'number',
      key: 'decimal',
      min: 0,
      max: 18,
      decimal: 0,
      label: Formdict['header.form.decimal'],
      initVal: card.decimal || 0,
      required: true
    },
    {
      type: 'select',
      key: 'format',
      label: Formdict['header.form.format'],
      initVal: card.format || '',
      options: [{
        value: '',
        text: Formdict['header.form.empty']
      }, {
        value: 'thdSeparator',
        text: Formdict['header.form.thdSeparator']
      }],
      required: false
    },
    {
      type: 'text',
      key: 'prefix',
      label: Formdict['header.form.prefix'],
      initVal: card.prefix || '',
      required: false,
      readonly: false
    },
    {
      type: 'text',
      key: 'postfix',
      label: Formdict['header.form.postfix'],
      initVal: card.postfix || '',
      tooltipClass: 'middle',
      required: false,
      readonly: false
    },
    {
      type: 'select',
      key: 'match',
      label: Formdict['header.form.match'],
      initVal: card.match || '',
      options: [{
        value: '',
        text: Formdict['header.form.empty']
      }, {
        value: '>',
        text: '>'
      }, {
        value: '<',
        text: '<'
      }, {
        value: '>=',
        text: '>='
      }, {
        value: '<=',
        text: '<='
      }],
      required: false
    },
    {
      type: 'text',
      key: 'matchVal',
      min: -Infinity,
      max: Infinity,
      decimal: 0,
      label: Formdict['header.form.matchVal'],
      initVal: card.matchVal || '',
      required: false,
      readonly: false
    },
    {
      type: 'select',
      key: 'color',
      label: Formdict['header.form.color'],
      initVal: card.color || '',
      options: [{
        value: '',
        text: Formdict['header.form.empty']
      }, {
        value: 'red',
        text: '红色（内容）'
      }, {
        value: 'redbg',
        text: '红色（背景）'
      }, {
        value: 'orange',
        text: '橙色（内容）'
      }, {
        value: 'orangebg',
        text: '橙色（背景）'
      }, {
        value: 'green',
        text: '绿色（内容）'
      }, {
        value: 'greenbg',
        text: '绿色（背景）'
      }],
      required: false
    },
    {
      type: 'number',
      key: 'fieldlength',
      label: Formdict['header.form.field.length'],
      initVal: card.fieldlength || (card.type === 'text' ? 50 : 512),
      required: false
    },
    {
      type: 'multiselect',
      key: 'blacklist',
      label: Formdict['header.form.blacklist'],
      initVal: card.blacklist || [],
      required: false,
      options: roleList
    },
    {
      type: 'cascader',
      key: 'linkmenu',
      label: Formdict['header.form.linkmenu'],
      initVal: card.linkmenu || [],
      required: false,
      options: menulist
    },
    {
      type: 'radio',
      key: 'scale',
      label: Formdict['header.form.clickscale'],
      initVal: card.scale || 'false',
      required: false,
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    }
  ]
}

/**
 * @description 获取表单配置信息
 * @param {*} card 
 * @param {*} inputfields 
 */
export function getModalForm (card, inputfields, linkableFields, linksupFields, subtable = false, roleList = []) {
  let _openType = []
  let _fieldlength = 50

  if (subtable) {
    _openType.push({
      value: 'linkMain',
      text: Formdict['header.form.linkMain']
    })
  }

  if (card.type === 'textarea' || card.type === 'fileupload' || card.type === 'multiselect') {
    _fieldlength = 512
  }

  return [
    {
      type: 'text',
      key: 'label',
      label: Formdict['header.form.name'],
      initVal: card.label,
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'field',
      label: Formdict['header.form.field'],
      initVal: card.field || '',
      required: true,
      readonly: false
    },
    {
      type: 'select',
      key: 'type',
      label: Formdict['header.form.type'],
      initVal: card.type,
      required: true,
      options: [{
        value: 'text',
        text: Formdict['header.form.text']
      }, {
        value: 'number',
        text: Formdict['header.form.number']
      }, {
        value: 'select',
        text: Formdict['header.form.select']
      }, {
        value: 'multiselect',
        text: Formdict['header.form.multiselect']
      }, {
        value: 'link',
        text: Formdict['header.form.link']
      }, {
        value: 'fileupload',
        text: Formdict['header.form.fileupload']
      }, {
        value: 'date',
        text: Formdict['header.form.dateday']
      }, {
        value: 'datemonth',
        text: Formdict['header.form.datemonth']
      }, {
        value: 'datetime',
        text: Formdict['header.form.datetime']
      }, {
        value: 'textarea',
        text: Formdict['header.form.textarea']
      }, {
        value: 'funcvar',
        text: Formdict['header.form.funcvar']
      },
      ..._openType]
    },
    {
      type: 'text',
      key: 'initval',
      label: Formdict['header.form.initval'],
      initVal: card.initval || '',
      required: false
    },
    {
      type: 'radio',
      key: 'resourceType',
      label: Formdict['header.form.resourceType'],
      initVal: card.resourceType || '0',
      required: true,
      options: [{
        value: '0',
        text: Formdict['header.form.custom']
      }, {
        value: '1',
        text: Formdict['header.form.datasource']
      }]
    },
    {
      type: 'radio',
      key: 'setAll',
      label: Formdict['header.form.setAll'],
      initVal: card.setAll || 'false',
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'textarea',
      key: 'dataSource',
      label: Formdict['header.form.datasource'],
      initVal: card.dataSource || '',
      required: true,
      readonly: false
    },
    {
      type: 'options',
      key: 'options',
      label: '',
      initVal: card.options || [],
      required: true,
      readonly: false
    },
    {
      type: 'select',
      key: 'linkField',
      label: Formdict['header.form.linkField'],
      initVal: card.linkField || '',
      required: true,
      readonly: false,
      options: linkableFields
    },
    {
      type: 'text',
      key: 'valueField',
      label: Formdict['header.form.valueField'],
      initVal: card.valueField || '',
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'valueText',
      label: Formdict['header.form.valueText'],
      initVal: card.valueText || '',
      required: true,
      readonly: false
    },
    {
      type: 'text',
      key: 'orderBy',
      label: Formdict['header.form.orderBy'],
      initVal: card.orderBy || '',
      required: false,
      readonly: false
    },
    {
      type: 'select',
      key: 'orderType',
      label: Formdict['header.form.orderType'],
      initVal: card.orderType || 'asc',
      options: [{
        value: 'asc',
        text: Formdict['header.form.asc']
      }, {
        value: 'desc',
        text: Formdict['header.form.desc']
      }]
    },
    {
      type: 'number',
      key: 'decimal',
      label: Formdict['header.form.decimal'],
      initVal: card.decimal || 0,
      required: true
    },
    {
      type: 'number',
      key: 'min',
      label: '最小值',
      initVal: card.min || '',
      required: false
    },
    {
      type: 'number',
      key: 'max',
      label: '最大值',
      initVal: card.max || '',
      required: false
    },
    {
      type: 'radio',
      key: 'readonly',
      label: Formdict['header.form.readonly'],
      initVal: card.readonly || 'false',
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'radio',
      key: 'required',
      label: Formdict['header.form.field.required'],
      initVal: card.required || 'true',
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'radio',
      key: 'hidden',
      label: Formdict['header.form.field.ishidden'],
      initVal: card.hidden || 'false',
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'radio',
      key: 'database',
      label: Formdict['header.form.database'],
      initVal: card.database || 'local',
      options: [{
        value: 'local',
        text: Formdict['header.form.database.local']
      }, {
        value: 'sso',
        text: Formdict['header.form.database.sso']
      }]
    },
    {
      type: 'radio',
      key: 'readin',
      label: Formdict['header.form.readin'],
      tooltip: Formdict['header.form.readin.tooltip'],
      initVal: card.readin || 'true',
      options: [{
        value: 'true',
        text: Formdict['header.form.true']
      }, {
        value: 'false',
        text: Formdict['header.form.false']
      }]
    },
    {
      type: 'number',
      key: 'fieldlength',
      label: Formdict['header.form.field.length'],
      tooltip: '文本、下拉框、日期等字段默认长度为50，多行文本与文件上传字段默认长度为512',
      initVal: card.fieldlength || _fieldlength,
      required: false
    },
    {
      type: 'number',
      key: 'maxRows',
      label: Formdict['header.form.maxRows'],
      initVal: card.maxRows || 6,
      required: false
    },
    {
      type: 'select',
      key: 'regular',
      label: Formdict['header.form.regular'],
      initVal: card.regular || '',
      options: [{
        value: '',
        text: Formdict['header.form.empty']
      }, {
        value: 'number',
        text: Formdict['header.form.number']
      }, {
        value: 'letter',
        text: Formdict['header.form.letter']
      }, {
        value: 'letter&number',
        text: Formdict['header.form.letter&number']
      }]
    },
    {
      type: 'select',
      key: 'supField',
      label: '上级表单',
      tooltip: '上级表单为下拉选择或关联菜单，设置上级表单后，该表单受控于上级菜单，注：受控关系在该表单隐藏时失效。',
      initVal: card.supField || '',
      required: false,
      readonly: false,
      options: linksupFields
    },
    {
      type: 'text',
      key: 'supvalue',
      label: '显示值',
      tooltip: '选择上级表单后，填写显示值，只有上级表单值与显示值相同时，该表单才会显示，注：多个值用逗号分隔。',
      initVal: card.supvalue || '',
      required: true,
      readonly: false
    },
    {
      type: 'select',
      key: 'quick',
      label: Formdict['header.form.quickadd'],
      initVal: '',
      required: false,
      options: []
    },
    {
      type: 'multiselect',
      key: 'linkSubField',
      label: Formdict['header.form.linkForm'],
      initVal: card.linkSubField || [],
      options: inputfields
    },
    {
      type: 'select',
      key: 'fileType',
      label: '显示方式',
      initVal: card.fileType || 'text',
      options: [{
        value: 'picture',
        text: '图文信息'
      }, {
        value: 'picture-card',
        text: '图片卡'
      }, {
        value: 'text',
        text: '文件'
      }]
    },
    {
      type: 'number',
      key: 'maxfile',
      label: '最大文件数',
      initVal: card.maxfile || '',
      required: false
    },
    {
      type: 'multiselect',
      key: 'blacklist',
      label: Formdict['header.form.blacklist'],
      initVal: card.blacklist || [],
      required: false,
      options: roleList
    }
  ]
}